pyproj Documentation
====================

Python interface to  `PROJ <https://proj.org/>`_ (cartographic projections and coordinate transformations library).

GitHub Repository: https://github.com/pyproj4/pyproj

.. note:: Minimum supported PROJ version is 7.2.0

.. note:: Minimum supported Python version is 3.7

.. note:: pyproj 3 wheels do not include transformation grids.
          For migration assistance see: :ref:`transformation_grids`

.. note:: pyproj 3+ no longer supports manylinux1 wheels.
          pip>=19.0 is required to install manylinux2010 wheels.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   installation
   examples
   transformation_grids
   gotchas
   api/index
   cli
   advanced_examples
   build_crs
   build_crs_cf
   crs_compatibility
   optimize_transformations
   history
   past_versions

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
